# AI Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.1] - 2023-10-11

### Fixed

-   Use the correct request structure when using the OpenAI Chat API

## [1.1.0] - 2023-10-11

### Changed

-   `BackendProtocol` is now `AIBackend`
-   Slight code restructure to fix installation/import issues with registered backends

## [1.0.0] - 2023-10-09

### Added

-   EveryAI is now a thing - separated out from Wagtail AI

## [Unreleased]

<!-- TEMPLATE - keep below to copy for new releases -->
<!--


## [x.y.z] - YYYY-MM-DD

### Added

- ...

### Changed

- ...

### Removed

- ...

-->
